@@ -13,37 +13,36 @@ logger_main = logging.getLogger(__name__)
 
 @runtime_checkable
 class ReportProtocol(Protocol):
-    """
-    Protocol class for report object.
+    """Protocol class for report object.
 
-    :param name: Report name, propagated to report file name
+    :param name: report name, propagated to report file name
     :type name: str
-    :param id: Report id, identification number of the report in SFDC
+    :param id: report id
     :type id: str
-    :param path: Report path, save location for the report in form of Path object
-    :type path: PathLike
-    :param type: Report type, allowed options ['SFDC'], type drives connector and report objects selection
+    :param path: report path, save location for the report in form of :class:`pathlib.Path` object
+    :type path: :class:`os.PathLike`
+    :param type: report type, drives connector selection
     :type type: str
-    :param export_params: Default parameters required by SFDC. Defaults to '?export=csv&enc=UTF-8&isdtp=p1'.
+    :param export_params: default GET parameters
     :type export_params: str
-    :param downloaded: Flag indicating whether the reports has been succesfully downloaded or not
+    :param downloaded: flag indicating whether the reports has been succesfully downloaded or not
     :type downloaded: bool
-    :param valid: Flag indicating whether the response has been succesfully retrieved or not
+    :param valid: flag indicating whether the response has been succesfully retrieved or not
     :type valid: bool
-    :param created_date: Report save completition date
+    :param created_date: report save completition date
     :type created_date: datetime
-    :param pull_date: Report response completition date
+    :param pull_date: report response completition date
     :type pull_date: datetime
-    :param processing_time: The time it took to process the report in seconds 
+    :param processing_time: the time it took to process the report in seconds 
     :type pull_date: timedelta
-    :param attempt_count: Number of attempts to process the report 
+    :param attempt_count: number of attempts to process the report 
     :type attempt_count: int
-    :param size: Size of saved report file in Mb
+    :param size: size of saved report file in Mb
     :type size: float
-    :param response: Container for request response
+    :param response: container for request response
     :type response: str
-    :param content: Pandas DataFrame based on response
-    :type content: DataFrame
+    :param content: Pandas :class:`pd.DataFrame` based on response
+    :type content: :class:`pd.DataFrame`
     """
 
     name: str
@@ -66,22 +65,22 @@ class ReportProtocol(Protocol):
 class ReportsContainerProtocol(Protocol):
     """Protocol class for report container object.
 
-    :param report_params_list: Collection of dicts with parameters for object crafting.
+    :param report_params_list: collection of dictionaries with parameters for object crafting
     :type report_params_list: list[dict[str, Any]]
-    :param summary_report_path: Path to save location of summary report.
-    :type summary_report_path: PathLike
+    :param summary_report_path: path to save location of summary report
+    :type summary_report_path: :class:`os.PathLike`
     """
 
     def create_reports(self) -> list[ReportProtocol]:
         """Orchestrating method to handle report objects factory
 
-        :return: Collection of Reports
-        :rtype: list[ReportProtocol]
+        :return: collection of :class:`ReportProtocol` objects
+        :rtype: list[:class:`ReportProtocol`]
         """
         ...
 
     def create_summary_report(self) -> None:
-        """Creates summary report which consist of all important details regarding Report objects. 
+        """Creates summary report which consist of all important details regarding :class:`ReportProtocol` objects. 
         Summary report is generated once all the reports are completed.
         """
         ...
@@ -89,36 +88,36 @@ class ReportsContainerProtocol(Protocol):
 
 @dataclass(slots=True)
 class SfdcReport():
-    """Concrete class representing Report object from SFDC.
+    """Concrete class representing SFDC Report object.
 
-    :param name: Report name, propagated to report file name.
+    :param name: report name, propagated to report file name
     :type name: str
-    :param id: Report id, identification number of the report in SFDC.
+    :param id: report id, identification number of the report in SFDC
     :type id: str
-    :param path: Report path, save location for the report in form of Path object.
-    :type path: PathLike
-    :param type: Report type, allowed options ['SFDC'], type drives connector and report objects selection. Defaults to 'SFDC'.
-    :type type: str
-    :param export_params: Default parameters required by SFDC. Defaults to '?export=csv&enc=UTF-8&isdtp=p1'.
-    :type export_params: str
-    :param downloaded: Flag indicating whether the reports has been succesfully downloaded or not. Defaults to False.
-    :type downloaded: bool
-    :param valid: Flag indicating whether the response has been succesfully retrieved or not. Defaults to False.
-    :type valid: bool
-    :param created_date: Report save completition date. Defaults to current datetime.
-    :type created_date: datetime
-    :param pull_date: Report response completition date. Defaults to current datetime.
-    :type pull_date: datetime
-    :param processing_time: The time it took to process the report in seconds. Defaults to 0 microseconds.
-    :type pull_date: timedelta
-    :param attempt_count: Number of attempts to process the report. Defaults to 0 .
-    :type attempt_count: int
-    :param size: Size of saved report file in Mb. Defaults to 0.0 .
-    :type size: float
-    :param response: Container for request response. Defaults to empty string.
-    :type response: str
-    :param content: Pandas DataFrame based on response. Defaults to empty Pandas DataFrame.
-    :type content: DataFrame
+    :param path: report path, save location for the report in form of :class:`pathlib.Path` object
+    :type path: :class:`os.PathLike`
+    :param type: report type, type drives connector and report objects selectiond, defaults to 'SFDC'
+    :type type: str, optional
+    :param export_params: default GET parameters required by SFDC, defaults to '?export=csv&enc=UTF-8&isdtp=p1'
+    :type export_params: str, optional
+    :param downloaded: flag indicating whether the reports has been succesfully downloaded or not, defaults to False
+    :type downloaded: bool, optional
+    :param valid: flag indicating whether the response has been succesfully retrieved or not, defaults to False
+    :type valid: bool, optional
+    :param created_date: report save completition date, defaults to current datetime
+    :type created_date: datetime, optional
+    :param pull_date: report response completition date, defaults to current datetime
+    :type pull_date: datetime, optional
+    :param processing_time: the time it took to process the report in seconds, defaults to 0 microseconds
+    :type pull_date: timedelta, optional
+    :param attempt_count: number of attempts to process the report, defaults to 0
+    :type attempt_count: int, optional
+    :param size: size of saved report file in Mb, defaults to 0.0
+    :type size: float, optional
+    :param response: container for request response, defaults ""
+    :type response: str, optional
+    :param content: Pandas DataFrame based on response, defaults to empty :class:`pd.DataFrame`
+    :type content: :class:`pd.DataFrame` , optional
     """
 
     name: str
@@ -154,18 +153,18 @@ class ReportsContainer():
         self.create_reports()
 
     def __len__(self):
-        """Returns number of collected Report objects.
+        """Returns number of collected :class:`ReportProtocol` objects.
         """
 
         return len(self.reports_list)
 
     def _create_sfdc_reports(self) -> Generator[SfdcReport, None, None]:
-        """SFDC Report objects factory
+        """Creates :class:`SfdcReport` objects.
 
-        :return: Generator with SFDC Reeport objects
-        :rtype: Generator[SfdcReport, None, None]
-        :yield: SFDC Report instance based on parsed report parameters
-        :rtype: SfdcReport
+        :return: generator with :class:`SfdcReport` objects
+        :rtype: Generator[:class:`SfdcReport`, None, None]
+        :yield: :class:`SfdcReport` instance based on parsed report parameters
+        :rtype: :class:`SfdcReport`
         """
 
         logger_main.debug("Creating SFDC report objects")
@@ -174,10 +173,10 @@ class ReportsContainer():
         return reports
 
     def create_reports(self) -> list[ReportProtocol]:
-        """Orchestrating method to handle report objects factory
+        """Orchestrating method to handle report objects crafting
 
-        :return: Collection of Reports
-        :rtype: list[ReportProtocol]
+        :return: collection of :class:`ReportProtocol` objects
+        :rtype: list[:class:`ReportProtocol`]
         """
 
         logger_main.debug("Creating all report objects")
@@ -186,14 +185,16 @@ class ReportsContainer():
         return self.reports_list
     
     def _create_summary_folder_if_not_exist(self):
+        """Creates folder for summary report if doesn't exist.
+        """
         if self.summary_path is not None:
             if not os.path.exists(os.path.dirname(self.summary_path)):
                 os.makedirs(os.path.dirname(self.summary_path))
         return None
 
     def create_summary_report(self) -> None:
-        """Creates summary report which consist of all important details regarding reports. 
-        Report is generated once all the reports are completed.
+        """Creates summary report which consist of all important details regarding :class:`ReportProtocol` objects. 
+        Summary is generated once all the :class:`ReportProtocol` are completed.
         """
         if self.summary_path:
             logger_main.debug("Creating summary report, saved in %s",
@@ -216,8 +217,8 @@ class ReportsContainer():
         return None
     
     def print_summary_table(self) -> None:
-        """Prints summary report which consist of all important details regarding reports. 
-        Report is generated once all the reports are completed.
+        """Prints summary table which consist of all important details regarding :class:`ReportProtocol` objects. 
+        Table is generated once all the :class:`ReportProtocol` are completed.
         """
         logger_main.debug("Creating summary table")
 
